#!/usr/bin/env bash

########################################################################################################################
# This job creates symlinks between the output of ecEarth and CMOR json tables 
# to be executed by the tasks.
#
# In this script, I call data the original data to be symlinked and workflow the 
# workflow that is executing this script
#
# VARIABLE INDEX:
#
# ECEARTH_OUTPUT: path to the experiment which we will link its data (/gpfs/scratch/bsc32/bsc032371/cxxx)
# AVAILABLE_COMPONENTS: components that are in the data (ifs, nemo, lpjg) 
# DATA_MEMBER%: member of the original data (fc0)
# DATA_CHUNK%: chunk we will link to 
#
#
# Manuel G. Marciani
# BSC-CNS - Earth Sciences Department
# 2024
#
########################################################################################################################

# check if the folder exists
mkdir -p %CURRENT_ROOTDIR%/19900201/fc0/runtime/output/ifs/001 
pushd %CURRENT_ROOTDIR%/19900201/fc0/runtime/output/ifs/001
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/ifs/001/ICMGGa79h+000000 ICMGG%EXPID%+000000
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/ifs/001/ICMGGa79h+000000 ICMSH%EXPID%+000000
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/ifs/001/ICMGGa79h+000000 ICMGG%EXPID%+199002
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/ifs/001/ICMGGa79h+000000 ICMSH%EXPID%+199002
popd 

mkdir -p %CURRENT_ROOTDIR%/19900201/fc0/runtime/output/nemo/
pushd %CURRENT_ROOTDIR%/19900201/fc0/runtime/output/nemo/
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/ofx-data 
mkdir 001
pushd 001 
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1d_19900201_19900228_lim_grid_T_2D.nc %EXPID%_1d_19900201_19900228_lim_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1d_19900201_19900228_lim_grid_U_2D.nc %EXPID%_1d_19900201_19900228_lim_grid_U_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1d_19900201_19900228_lim_grid_V_2D.nc %EXPID%_1d_19900201_19900228_lim_grid_V_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1d_19900201_19900228_opa_grid_T_2D.nc %EXPID%_1d_19900201_19900228_opa_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_lim_grid_T_2D.nc %EXPID%_1m_19900201_19900228_lim_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_lim_grid_U_2D.nc %EXPID%_1m_19900201_19900228_lim_grid_U_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_lim_grid_V_2D.nc %EXPID%_1m_19900201_19900228_lim_grid_V_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_1point.nc %EXPID%_1m_19900201_19900228_opa_grid_1point.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_ptr_T_3basin_2D.nc %EXPID%_1m_19900201_19900228_opa_grid_ptr_T_3basin_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_T_2D.nc %EXPID%_1m_19900201_19900228_opa_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_T_3D.nc %EXPID%_1m_19900201_19900228_opa_grid_T_3D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_U_2D.nc %EXPID%_1m_19900201_19900228_opa_grid_U_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_U_3D.nc %EXPID%_1m_19900201_19900228_opa_grid_U_3D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_V_2D.nc %EXPID%_1m_19900201_19900228_opa_grid_V_2D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_V_3D.nc %EXPID%_1m_19900201_19900228_opa_grid_V_3D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_grid_W_3D.nc %EXPID%_1m_19900201_19900228_opa_grid_W_3D.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_vert_sum.nc %EXPID%_1m_19900201_19900228_opa_vert_sum.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_zoom_2000_sum.nc %EXPID%_1m_19900201_19900228_opa_zoom_2000_sum.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_zoom_300_sum.nc %EXPID%_1m_19900201_19900228_opa_zoom_300_sum.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1m_19900201_19900228_opa_zoom_700_sum.nc %EXPID%_1m_19900201_19900228_opa_zoom_700_sum.nc
ln -s %ECEARTH_OUTPUT%/19900201/fc0/runtime/output/nemo/001/a79h_1y_19900201_19900228_opa_grid_T_2D.nc %EXPID%_1y_19900201_19900228_opa_grid_T_2D.nc
popd 
popd 
